macro_rules! internal_err {
($($e:expr),* $(,)?) => { ... };
}Expand description
Constructs a PlanError::Internal. Prefer this over sql_err! whenever the
situation reflects a Materialize bug rather than a user error.
macro_rules! internal_err {
($($e:expr),* $(,)?) => { ... };
}Constructs a PlanError::Internal. Prefer this over sql_err! whenever the
situation reflects a Materialize bug rather than a user error.