macro_rules! bail_internal {
($($e:expr),* $(,)?) => { ... };
}Expand description
Returns a PlanError::Internal from the current function. Prefer this over
sql_bail! whenever the situation reflects a Materialize bug rather than a
user error (e.g., an invariant that is supposed to be enforced by the
parser, name resolution, or purification).